@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2012-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -36,17 +36,14 @@ public:
     {
     }
 
-    ~AutoCorrectionWidgetPrivate()
-    {
-        delete ui;
-    }
+    ~AutoCorrectionWidgetPrivate() = default;
 
     AutoCorrection::TypographicQuotes m_singleQuotes;
     AutoCorrection::TypographicQuotes m_doubleQuotes;
     QSet<QString> m_upperCaseExceptions;
     QSet<QString> m_twoUpperLetterExceptions;
     QHash<QString, QString> m_autocorrectEntries;
-    Ui::AutoCorrectionWidget *const ui;
+    std::unique_ptr<Ui::AutoCorrectionWidget> const ui;
     AutoCorrection *mAutoCorrection = nullptr;
     bool mWasChanged = false;
 };
@@ -105,7 +102,7 @@ AutoCorrectionWidget::AutoCorrectionWidget(QWidget *parent)
     connect(d->ui->abbreviationList, &PimCommon::AutoCorrectionListWidget::deleteSelectedItems, this, &AutoCorrectionWidget::removeAbbreviationEntry);
     connect(d->ui->twoUpperLetterList, &PimCommon::AutoCorrectionListWidget::itemSelectionChanged, this, &AutoCorrectionWidget::slotEnableDisableTwoUpperEntry);
     connect(d->ui->twoUpperLetterList, &PimCommon::AutoCorrectionListWidget::deleteSelectedItems, this, &AutoCorrectionWidget::removeTwoUpperLetterEntry);
-    connect(d->ui->autocorrectionLanguage, QOverload<int>::of(&PimCommon::AutoCorrectionLanguage::activated), this, &AutoCorrectionWidget::changeLanguage);
+    connect(d->ui->autocorrectionLanguage, &PimCommon::AutoCorrectionLanguage::activated, this, &AutoCorrectionWidget::changeLanguage);
     connect(d->ui->addNonBreakingSpaceInFrench, &QCheckBox::clicked, this, &AutoCorrectionWidget::emitChanged);
     connect(d->ui->twoUpperLetter, &QLineEdit::returnPressed, this, &AutoCorrectionWidget::addTwoUpperLetterEntry);
     connect(d->ui->abbreviation, &QLineEdit::returnPressed, this, &AutoCorrectionWidget::addAbbreviationEntry);
@@ -128,10 +125,7 @@ AutoCorrectionWidget::AutoCorrectionWidget(QWidget *parent)
     connect(d->ui->exportAutoCorrection, &QPushButton::clicked, this, &AutoCorrectionWidget::slotExportAutoCorrection);
 }
 
-AutoCorrectionWidget::~AutoCorrectionWidget()
-{
-    delete d;
-}
+AutoCorrectionWidget::~AutoCorrectionWidget() = default;
 
 void AutoCorrectionWidget::setAutoCorrection(AutoCorrection *autoCorrect)
 {
@@ -166,11 +160,11 @@ void AutoCorrectionWidget::loadAutoCorrectionAndException()
 {
     /* tab 2 - Custom Quotes */
     d->m_singleQuotes = d->mAutoCorrection->typographicSingleQuotes();
-    d->ui->singleQuote1->setText(d->m_singleQuotes.begin);
-    d->ui->singleQuote2->setText(d->m_singleQuotes.end);
+    d->ui->simpleQuoteBeginReplace->setText(d->m_singleQuotes.begin);
+    d->ui->simpleQuoteEndReplace->setText(d->m_singleQuotes.end);
     d->m_doubleQuotes = d->mAutoCorrection->typographicDoubleQuotes();
-    d->ui->doubleQuote1->setText(d->m_doubleQuotes.begin);
-    d->ui->doubleQuote2->setText(d->m_doubleQuotes.end);
+    d->ui->doubleQuoteBeginReplace->setText(d->m_doubleQuotes.begin);
+    d->ui->doubleQuoteEndReplace->setText(d->m_doubleQuotes.end);
     enableSingleQuotes(d->ui->typographicSingleQuotes->isChecked());
     enableDoubleQuotes(d->ui->typographicDoubleQuotes->isChecked());
 
@@ -277,7 +271,7 @@ void AutoCorrectionWidget::selectSingleQuoteCharOpen()
     dlg->autoInsertChar();
     if (dlg->exec()) {
         d->m_singleQuotes.begin = dlg->currentChar();
-        d->ui->singleQuote1->setText(d->m_singleQuotes.begin);
+        d->ui->simpleQuoteBeginReplace->setText(d->m_singleQuotes.begin);
         emitChanged();
     }
     delete dlg;
@@ -291,7 +285,7 @@ void AutoCorrectionWidget::selectSingleQuoteCharClose()
     dlg->autoInsertChar();
     if (dlg->exec()) {
         d->m_singleQuotes.end = dlg->currentChar();
-        d->ui->singleQuote2->setText(d->m_singleQuotes.end);
+        d->ui->simpleQuoteEndReplace->setText(d->m_singleQuotes.end);
         emitChanged();
     }
     delete dlg;
@@ -300,8 +294,8 @@ void AutoCorrectionWidget::selectSingleQuoteCharClose()
 void AutoCorrectionWidget::setDefaultSingleQuotes()
 {
     d->m_singleQuotes = d->mAutoCorrection->typographicDefaultSingleQuotes();
-    d->ui->singleQuote1->setText(d->m_singleQuotes.begin);
-    d->ui->singleQuote2->setText(d->m_singleQuotes.end);
+    d->ui->simpleQuoteBeginReplace->setText(d->m_singleQuotes.begin);
+    d->ui->simpleQuoteEndReplace->setText(d->m_singleQuotes.end);
     emitChanged();
 }
 
@@ -313,7 +307,7 @@ void AutoCorrectionWidget::selectDoubleQuoteCharOpen()
     dlg->autoInsertChar();
     if (dlg->exec()) {
         d->m_doubleQuotes.begin = dlg->currentChar();
-        d->ui->doubleQuote1->setText(d->m_doubleQuotes.begin);
+        d->ui->doubleQuoteBeginReplace->setText(d->m_doubleQuotes.begin);
         emitChanged();
     }
     delete dlg;
@@ -327,7 +321,7 @@ void AutoCorrectionWidget::selectDoubleQuoteCharClose()
     dlg->autoInsertChar();
     if (dlg->exec()) {
         d->m_doubleQuotes.end = dlg->currentChar();
-        d->ui->doubleQuote2->setText(d->m_doubleQuotes.end);
+        d->ui->doubleQuoteEndReplace->setText(d->m_doubleQuotes.end);
         emitChanged();
     }
     delete dlg;
@@ -336,8 +330,8 @@ void AutoCorrectionWidget::selectDoubleQuoteCharClose()
 void AutoCorrectionWidget::setDefaultDoubleQuotes()
 {
     d->m_doubleQuotes = d->mAutoCorrection->typographicDefaultDoubleQuotes();
-    d->ui->doubleQuote1->setText(d->m_doubleQuotes.begin);
-    d->ui->doubleQuote2->setText(d->m_doubleQuotes.end);
+    d->ui->doubleQuoteBeginReplace->setText(d->m_doubleQuotes.begin);
+    d->ui->doubleQuoteEndReplace->setText(d->m_doubleQuotes.end);
     emitChanged();
 }
 
@@ -606,7 +600,11 @@ void AutoCorrectionWidget::changeLanguage(int index)
         return;
     }
     if (d->mWasChanged) {
-        const int rc = KMessageBox::warningYesNo(this, i18n("Language was changed, do you want to save config for previous language?"), i18n("Save config"));
+        const int rc = KMessageBox::warningYesNo(this,
+                                                 i18n("Language was changed, do you want to save config for previous language?"),
+                                                 i18n("Save config"),
+                                                 KStandardGuiItem::save(),
+                                                 KStandardGuiItem::discard());
         if (rc == KMessageBox::Yes) {
             writeConfig();
         }
