@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2012-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -94,6 +94,9 @@ bool ImportLibreOfficeAutocorrection::importFile(Type type, const KArchiveDirect
         const auto archiveFile = static_cast<const KArchiveFile *>(documentList);
         archiveFile->copyTo(mTempDir->path());
         QFile file(mTempDir->path() + QLatin1Char('/') + archiveFileName);
+        if (!file.open(QIODevice::ReadOnly)) {
+            qCWarning(PIMCOMMON_LOG) << "Impossible to open " << file.fileName();
+        }
         QDomDocument doc;
         if (loadDomElement(doc, &file)) {
             QDomElement list = doc.documentElement();
