@@ -1,11 +1,10 @@
 /*
-  SPDX-FileCopyrightText: 2012-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2012-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef IMPORTLIBREOFFICEAUTOCORRECTION_H
-#define IMPORTLIBREOFFICEAUTOCORRECTION_H
+#pragma once
 
 #include "importabstractautocorrection.h"
 
@@ -15,7 +14,8 @@ class QDomDocument;
 class QFile;
 class KArchiveDirectory;
 
-namespace PimCommon {
+namespace PimCommon
+{
 class ImportLibreOfficeAutocorrection : public ImportAbstractAutocorrection
 {
 public:
@@ -25,11 +25,7 @@ public:
     Q_REQUIRED_RESULT bool import(const QString &fileName, ImportAbstractAutocorrection::LoadAttribute loadAttribute = All) override;
 
 private:
-    enum Type {
-        DOCUMENT,
-        SENTENCE,
-        WORD
-    };
+    enum Type { DOCUMENT, SENTENCE, WORD };
 
     void importAutoCorrectionFile();
     void closeArchive();
@@ -40,4 +36,3 @@ private:
 };
 }
 
-#endif // IMPORTLIBREOFFICEAUTOCORRECTION_H
