@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -19,9 +19,7 @@ using namespace PimCommon;
 class PimCommon::CustomToolsWidgetNgPrivate
 {
 public:
-    CustomToolsWidgetNgPrivate()
-    {
-    }
+    CustomToolsWidgetNgPrivate() = default;
 
     QStackedWidget *mStackedWidget = nullptr;
     QList<PimCommon::CustomToolsViewInterface *> mListInterfaceView;
