@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2017-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -15,18 +15,16 @@ LogActivitiesWidgetTest::LogActivitiesWidgetTest(QObject *parent)
 {
 }
 
-LogActivitiesWidgetTest::~LogActivitiesWidgetTest()
-{
-}
+LogActivitiesWidgetTest::~LogActivitiesWidgetTest() = default;
 
 void LogActivitiesWidgetTest::shouldHaveDefaultValue()
 {
     PimCommon::LogActivitiesWidget w;
-    auto *mainLayout = w.findChild<QVBoxLayout *>(QStringLiteral("mainLayout"));
+    auto mainLayout = w.findChild<QVBoxLayout *>(QStringLiteral("mainLayout"));
     QVERIFY(mainLayout);
     QCOMPARE(mainLayout->contentsMargins(), QMargins(0, 0, 0, 0));
 
-    auto *mLog = w.findChild<KPIMTextEdit::PlainTextEditorWidget *>(QStringLiteral("log"));
+    auto mLog = w.findChild<KPIMTextEdit::PlainTextEditorWidget *>(QStringLiteral("log"));
     QVERIFY(mLog);
     QVERIFY(mLog->isReadOnly());
 }
