@@ -1,11 +1,10 @@
 /*
-  SPDX-FileCopyrightText: 2018-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2018-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef PURPOSEMENUWIDGET_H
-#define PURPOSEMENUWIDGET_H
+#pragma once
 
 #include "pimcommon_export.h"
 #include <QObject>
@@ -40,4 +39,3 @@ private:
 };
 }
 
-#endif // PURPOSEMENUWIDGET_H
