@@ -2,53 +2,27 @@
     simplestringlisteditor.h
 
     This file is part of KMail, the KDE mail client.
-    Copyright (c) 2001 Marc Mutz <mutz@kde.org>
+    SPDX-FileCopyrightText: 2001 Marc Mutz <mutz@kde.org>
 
-    Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
-    KMail is free software; you can redistribute it and/or modify it
-    under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    KMail is distributed in the hope that it will be useful, but
-    WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
-
-    In addition, as a special exception, the copyright holders give
-    permission to link the code of this program with any edition of
-    the Qt library by Trolltech AS, Norway (or with modified versions
-    of Qt that use the same license as Qt), and distribute linked
-    combinations including the two.  You must obey the GNU General
-    Public License in all respects for all of the code used other than
-    Qt.  If you modify this file, you may extend this exception to
-    your version of the file, but you are not obligated to do so.  If
-    you do not wish to do so, delete this exception statement from
-    your version.
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef SIMPLESTRINGLISTEDITOR_H
-#define SIMPLESTRINGLISTEDITOR_H
+#pragma once
 
-#include <QWidget>
 #include <QStringList>
+#include <QWidget>
 
 #include "pimcommon_export.h"
 
-class QListWidget;
-class QListWidgetItem;
-
 //
 //
 // SimpleStringListEditor (a listbox with "add..." and "remove" buttons)
 //
 //
-namespace PimCommon {
+namespace PimCommon
+{
 class SimpleStringListEditorPrivate;
 /**
  * @brief The SimpleStringListEditor class
@@ -71,7 +45,12 @@ public:
     };
 
     /** Constructor. Populates the list with @p strings. */
-    explicit SimpleStringListEditor(QWidget *parent = nullptr, ButtonCode buttons = Unsorted, const QString &addLabel = QString(), const QString &removeLabel = QString(), const QString &modifyLabel = QString(), const QString &addDialogLabel = QString());
+    explicit SimpleStringListEditor(QWidget *parent = nullptr,
+                                    ButtonCode buttons = Unsorted,
+                                    const QString &addLabel = QString(),
+                                    const QString &removeLabel = QString(),
+                                    const QString &modifyLabel = QString(),
+                                    const QString &addDialogLabel = QString());
 
     ~SimpleStringListEditor() override;
     /** Sets the list of strings displayed to @p strings */
@@ -94,8 +73,13 @@ public:
 
     Q_REQUIRED_RESULT virtual QString modifyEntry(const QString &text);
     void setAddDialogLabel(const QString &addDialogLabel);
+    void setAddDialogTitle(const QString &str);
+
+    void setModifyDialogTitle(const QString &str);
+    void setModifyDialogLabel(const QString &str);
 
     void setRemoveDialogLabel(const QString &removeDialogLabel);
+
 Q_SIGNALS:
     /** Connected slots can alter the argument to be added or set the
       argument to QString() to suppress adding.
@@ -119,8 +103,7 @@ protected Q_SLOTS:
 private:
     void slotContextMenu(const QPoint &);
     bool containsString(const QString &str);
-    SimpleStringListEditorPrivate *const d;
+    std::unique_ptr<SimpleStringListEditorPrivate> const d;
 };
 }
 
-#endif // SIMPLESTRINGLISTEDITOR_H
