@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -18,8 +18,8 @@
 #include <Akonadi/CollectionFetchJob>
 #include <Akonadi/CollectionFetchScope>
 #include <Akonadi/CollectionModifyJob>
-#include <ContactGroupExpandJob>
-#include <ContactGroupSearchJob>
+#include <Akonadi/ContactGroupExpandJob>
+#include <Akonadi/ContactGroupSearchJob>
 #include <KContacts/Addressee>
 #include <KLocalizedString>
 #include <KMessageBox>
@@ -36,9 +36,7 @@ AclModifyJob::AclModifyJob(QObject *parent)
     connect(this, &AclModifyJob::searchNextContact, this, &AclModifyJob::searchContact);
 }
 
-AclModifyJob::~AclModifyJob()
-{
-}
+AclModifyJob::~AclModifyJob() = default;
 
 void AclModifyJob::searchContact()
 {
