@@ -6,13 +6,13 @@
  *  SPDX-License-Identifier: GPL-2.0-or-later
  */
 
-#ifndef COLLECTIONACLPAGE_H
-#define COLLECTIONACLPAGE_H
+#pragma once
 
-#include <AkonadiWidgets/CollectionPropertiesPage>
 #include "pimcommonakonadi_export.h"
+#include <Akonadi/CollectionPropertiesPage>
 
-namespace PimCommon {
+namespace PimCommon
+{
 class CollectionAclPagePrivate;
 /**
  * "Access Control" tab in the folder dialog
@@ -34,9 +34,8 @@ protected:
     void init();
 
 private:
-    CollectionAclPagePrivate *const d;
+    std::unique_ptr<CollectionAclPagePrivate> const d;
 };
 AKONADI_COLLECTION_PROPERTIES_PAGE_FACTORY(CollectionAclPageFactory, CollectionAclPage)
 }
 
-#endif
