@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -12,9 +12,7 @@
 
 using namespace PimCommon;
 
-BalooCompletionEmail::BalooCompletionEmail()
-{
-}
+BalooCompletionEmail::BalooCompletionEmail() = default;
 
 void BalooCompletionEmail::setEmailList(const QStringList &lst)
 {
@@ -73,7 +71,9 @@ QStringList BalooCompletionEmail::cleanupEmailList()
  */
 QString BalooCompletionEmail::stripEmail(const QString &email, QString &address)
 {
-    QString displayName, addrSpec, comment;
+    QString displayName;
+    QString addrSpec;
+    QString comment;
     if (KEmailAddress::AddressOk == KEmailAddress::splitAddress(email, displayName, addrSpec, comment)) {
         address = addrSpec;
         while (true) {
