@@ -1,12 +1,11 @@
 /*
-  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
 */
 
-#ifndef BLACKLISTBALOOEMAILCOMPLETIONWIDGET_H
-#define BLACKLISTBALOOEMAILCOMPLETIONWIDGET_H
+#pragma once
 
 #include "pimcommonakonadi_private_export.h"
 #include <QWidget>
@@ -57,4 +56,3 @@ private:
 };
 }
 
-#endif // BLACKLISTBALOOEMAILCOMPLETIONWIDGET_H
