@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -49,10 +49,10 @@ public:
     PimCommon::GenericPlugin *pluginFromIdentifier(const QString &id);
     void clearPluginActions(const QString &prefix, KXMLGUIClient *guiClient);
 private Q_SLOTS:
-    void slotPluginActivated(AbstractGenericPluginInterface *interface);
+    void slotPluginActivated(PimCommon::AbstractGenericPluginInterface *interface);
 
 private:
-    PluginInterfacePrivate *const d;
+    std::unique_ptr<PluginInterfacePrivate> const d;
 };
 }
 
