@@ -1,18 +1,18 @@
 /*
-  SPDX-FileCopyrightText: 2012-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2012-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef PIMCOMMONCREATERESOURCE_H
-#define PIMCOMMONCREATERESOURCE_H
+#pragma once
 
 #include "pimcommonakonadi_export.h"
+#include <QMap>
 #include <QObject>
 #include <QVariant>
-#include <QMap>
 
-namespace PimCommon {
+namespace PimCommon
+{
 /**
  * @brief The CreateResource class
  * @author Laurent Montel <montel@kde.org>
@@ -22,9 +22,12 @@ class PIMCOMMONAKONADI_EXPORT CreateResource : public QObject
     Q_OBJECT
 public:
     explicit CreateResource(QObject *parent = nullptr);
-    ~CreateResource();
+    ~CreateResource() override;
 
-    Q_REQUIRED_RESULT QString createResource(const QString &resources, const QString &name, const QMap<QString, QVariant> &settings, bool synchronizeTree = false);
+    Q_REQUIRED_RESULT QString createResource(const QString &resources,
+                                             const QString &name,
+                                             const QMap<QString, QVariant> &settings,
+                                             bool synchronizeTree = false);
 
 Q_SIGNALS:
     void createResourceInfo(const QString &);
@@ -32,4 +35,3 @@ Q_SIGNALS:
 };
 }
 
-#endif // CREATERESOURCE_H
